==> 0.0.2.tar.gz: ios/Classes/AdManager/YFAdsInsertManager.m <==

#import <Foundation/Foundation.h>
#import "YFAdsInsertManager.h"
#import "YFAdsConstant.h"
#import <Flutter/Flutter.h>
#import "YFAdsUtils.h"
#import <YFAdsSDK/YFAdInterstitial.h>

@interface YFAdsInsertManager ()<YFAdInterstitialDelegate>

@property (nonatomic, strong) FlutterEventSink flutterEventSink;
@property (nonatomic, strong) YFAdInterstitial *interstitial;
@property (nonatomic, strong) UIViewController *viewController;

@end

@implementation YFAdsInsertManager

-(instancetype)initWithParams:(FlutterEventSink)flutterEventSink viewController:(UIViewController *)viewController{
    self = [super init];
    _flutterEventSink = flutterEventSink;
    _viewController = viewController;
    return self;
}

-(void)showAd:(NSDictionary *)parametersDic {
    NSString *positionId = parametersDic[KEY_POSITION_ID];
    self.interstitial = [[YFAdInterstitial alloc]initWithAdUnitID:positionId viewController:self.viewController];
    self.interstitial.delegate = self;
    [self.interstitial loadAndShowAd];
    NSLog(@"YFAdsInsertManager positionId %@",positionId);

}


//#pragma mark WHInterstitialAdDelegate
//

//- (void)WHInterstitialAdShowFail:(WHTemplateInterstitialAd *)interstitialAd didFailWithError:(NSError *)error {
//    NSLog(@"WH插屏广告展示失败");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHInterstitialAdShowFail" forKey:KEY_METHOD];
//    [result setValue:error.localizedDescription forKey:KEY_ERROR];
//    [self callBack:result];
//}
/////插屏广告已曝光
//- (void)WHInterstitialAdDidExposure:(WHTemplateInterstitialAd *)interstitialAd {
//    NSLog(@"WH插屏广告已曝光");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHInterstitialAdDidExposure" forKey:KEY_METHOD];
//    [self callBack:result];
//}
///// 插屏广告被点击
//- (void)WHInterstitialAdDidClick:(WHTemplateInterstitialAd *)interstitialAd {
//    NSLog(@"WH插屏广告被点击");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHInterstitialAdDidClick" forKey:KEY_METHOD];
//    [self callBack:result];
//}
///// 插屏广告被关闭
//- (void)WHInterstitialAdDidClose:(WHTemplateInterstitialAd *)interstitialAd {
//    NSLog(@"WH插屏广告被关闭");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHInterstitialAdDidClose" forKey:KEY_METHOD];
//    [self callBack:result];
//}
//
-(void)callBack:(NSMutableDictionary *)resultDic{
    [resultDic setValue:AD_TYPE_INTERACTION forKey:KEY_AD_TYPE];
    NSString * result = [YFAdsUtils dictionary2JsonString:resultDic];
    _flutterEventSink(result);
}

- (void)deallocAd {
    self.interstitial.delegate = nil;
    self.interstitial = nil;
}

/// 广告数据加载成功
- (void)fcAdLoadSuccess:(YFAdBaseAdapter *)model {
    NSLog(@"广告数据加载成功");
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdDidLoad" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告曝光
- (void)fcAdExposured:(id)adapter  {
    NSLog(@"广告曝光回调 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdDidExposure" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告点击
- (void)fcAdClicked:(id)adapter  {
    NSLog(@"广告点击 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdDidClick" forKey:KEY_METHOD];
    [self callBack:result];

}

/// 广告加载失败
- (void)fcAdFailedWithError:(NSError *)error description:(NSDictionary *)description {
    NSLog(@"广告展示失败 %s  error: %@ 详情:%@", __func__, error, description);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdLoadFail" forKey:KEY_METHOD];
    [result setValue:error.localizedDescription forKey:KEY_ERROR];
    [self callBack:result];
    [self deallocAd];

}

/// 广告关闭了
- (void)fcAdDidClose:(id)adapter  {
    NSLog(@"广告关闭了 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdDidClose" forKey:KEY_METHOD];
    [self callBack:result];
    [self deallocAd];
}

-(void)dealloc {
    NSLog(@"插屏释放 %s",__func__);

}

@end

==> 0.0.9.tar.gz: ios/Classes/AdManager/YFAdsInsertManager.m <==

#import <Foundation/Foundation.h>
#import "YFAdsInsertManager.h"
#import "YFAdsConstant.h"
#import <Flutter/Flutter.h>
#import "YFAdsUtils.h"
#import <YFAdsSDK/YFAdInterstitial.h>

@interface YFAdsInsertManager ()<YFAdInterstitialDelegate>

@property (nonatomic, strong) FlutterEventSink flutterEventSink;
@property (nonatomic, strong) FlutterResult flutterResult;
@property (nonatomic, strong) YFAdInterstitial *interstitial;
@property (nonatomic, strong) UIViewController *viewController;

@end

@implementation YFAdsInsertManager



-(instancetype)initWithParams:(FlutterEventSink)flutterEventSink viewController:(UIViewController *)viewController result:(FlutterResult)flutterResult {
    self = [super init];
    _flutterEventSink = flutterEventSink;
    _viewController = viewController;
    _flutterResult = flutterResult;

    return self;
}

-(instancetype)initWithParams:(FlutterEventSink)flutterEventSink viewController:(UIViewController *)viewController{
    self = [super init];
    _flutterEventSink = flutterEventSink;
    _viewController = viewController;
    return self;
}


-(void)showAd {
    if (self.interstitial) {
        [self.interstitial showAd];
    }
}


-(void)loadAd:(NSDictionary *)parametersDic {
    NSString *positionId = parametersDic[KEY_POSITION_ID];
    self.interstitial = [[YFAdInterstitial alloc]initWithAdUnitID:positionId viewController:self.viewController];
    self.interstitial.delegate = self;
    [self.interstitial loadAd];
    NSLog(@"loadAd YFAdsInsertManager positionId %@",positionId);
}



-(void)loadAndShow:(NSDictionary *)parametersDic {
    NSString *positionId = parametersDic[KEY_POSITION_ID];
    self.interstitial = [[YFAdInterstitial alloc]initWithAdUnitID:positionId viewController:self.viewController];
    self.interstitial.delegate = self;
    [self.interstitial loadAndShowAd];
    NSLog(@"loadAndShow YFAdsInsertManager positionId %@",positionId);
}


//#pragma mark WHInterstitialAdDelegate
//

//- (void)WHInterstitialAdShowFail:(WHTemplateInterstitialAd *)interstitialAd didFailWithError:(NSError *)error {
//    NSLog(@"WH插屏广告展示失败");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHInterstitialAdShowFail" forKey:KEY_METHOD];
//    [result setValue:error.localizedDescription forKey:KEY_ERROR];
//    [self callBack:result];
//}
/////插屏广告已曝光
//- (void)WHInterstitialAdDidExposure:(WHTemplateInterstitialAd *)interstitialAd {
//    NSLog(@"WH插屏广告已曝光");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHInterstitialAdDidExposure" forKey:KEY_METHOD];
//    [self callBack:result];
//}
///// 插屏广告被点击
//- (void)WHInterstitialAdDidClick:(WHTemplateInterstitialAd *)interstitialAd {
//    NSLog(@"WH插屏广告被点击");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHInterstitialAdDidClick" forKey:KEY_METHOD];
//    [self callBack:result];
//}
///// 插屏广告被关闭
//- (void)WHInterstitialAdDidClose:(WHTemplateInterstitialAd *)interstitialAd {
//    NSLog(@"WH插屏广告被关闭");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHInterstitialAdDidClose" forKey:KEY_METHOD];
//    [self callBack:result];
//}
//
-(void)callBack:(NSMutableDictionary *)resultDic{
    [resultDic setValue:AD_TYPE_INTERACTION forKey:KEY_AD_TYPE];
    NSString * result = [YFAdsUtils dictionary2JsonString:resultDic];
    _flutterEventSink(result);
    _flutterResult(result);
}

- (void)deallocAd {
    self.interstitial.delegate = nil;
    self.interstitial = nil;
}

/// 广告数据加载成功
- (void)fcAdLoadSuccess:(YFAdBaseAdapter *)model {
    NSLog(@"广告数据加载成功");
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdDidLoad" forKey:KEY_METHOD];
    NSString *ecpm = [NSString stringWithFormat:@"%zd",model.ecpm];
    [result setValue:ecpm forKey:KEY_ECPM];
    [self callBack:result];
}

/// 广告曝光
- (void)fcAdExposured:(id)adapter  {
    NSLog(@"广告曝光回调 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdDidExposure" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告点击
- (void)fcAdClicked:(id)adapter  {
    NSLog(@"广告点击 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdDidClick" forKey:KEY_METHOD];

    [self callBack:result];

}

/// 广告加载失败
- (void)fcAdFailedWithError:(NSError *)error description:(NSDictionary *)description {
    NSLog(@"广告展示失败 %s  error: %@ 详情:%@", __func__, error, description);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdLoadFail" forKey:KEY_METHOD];
    [result setValue:error.localizedDescription forKey:KEY_ERROR];
    [self callBack:result];
    [self deallocAd];

}

/// 广告关闭了
- (void)fcAdDidClose:(id)adapter  {
    NSLog(@"广告关闭了 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfInterstitialAdDidClose" forKey:KEY_METHOD];
    [self callBack:result];
    [self deallocAd];
}

-(void)dealloc {
    NSLog(@"插屏释放 %s",__func__);

}

@end
